pub fn NativeCompositionPreview(props: NativeCompositionPreviewProps) -> ElementExpand description
Renders the current Player frame using the same Composition -> Scene path as export.
pub fn NativeCompositionPreview(props: NativeCompositionPreviewProps) -> ElementRenders the current Player frame using the same Composition -> Scene path as export.