pub struct CompositionHandle(/* private fields */);Expand description
Cloneable handle for passing a native composition through Dioxus props.
Implementations
Sourceimpl CompositionHandle
impl CompositionHandle
pub fn new<C>(composition: C) -> Selfwhere
C: Composition + 'static,
pub fn id(&self) -> &str
Sourcepub fn render_frame(
&self,
frame: u32,
input_props: &Value,
context: NativeCompositionContext,
) -> Result<Scene, CompositionError>
pub fn render_frame( &self, frame: u32, input_props: &Value, context: NativeCompositionContext, ) -> Result<Scene, CompositionError>
Prepare and render one frame through the shared export contract.